@@ -9,50 +9,46 @@
 ***************************************************************************/
 #include "KBlocksRepWin.h"
 
-#include <KLocale>
-#include <KStatusBar>
+#include <KLocalizedString>
+#include <QStatusBar>
 #include <QPixmapCache>
 
 #include <qdatetime.h>
 
-KBlocksRepWin::KBlocksRepWin(const char * replayFile, bool binaryMode) : KMainWindow()
+KBlocksRepWin::KBlocksRepWin(const char *replayFile, bool binaryMode) : KMainWindow()
 {
     //Use up to 3MB for global application pixmap cache
-    QPixmapCache::setCacheLimit(3*1024);
-    
+    QPixmapCache::setCacheLimit(3 * 1024);
+
     mpGameReplayer = new KBlocksGameReplayer(replayFile, binaryMode);
-    
+
     mGameCount = mpGameReplayer->getGameCount();
-    if (mGameCount == 0)
-    {
+    if (mGameCount == 0) {
         return;
     }
-    
+
     mpGameLogic = new KBlocksGameLogic(mpGameReplayer);
-    if (mpGameReplayer->isSameSeed())
-    {
+    if (mpGameReplayer->isSameSeed()) {
         mpGameLogic->setGameSeed(mpGameReplayer->getGameSeed());
-    }
-    else
-    {
+    } else {
         mpGameLogic->setGameSeed(-mpGameReplayer->getGameSeed());
     }
     mpGameLogic->setGamePunish(false);
     mpGameLogic->setGameStandbyMode(false);
     mpGameLogic->setInitInterval(0);
     mpGameLogic->setLevelUpInterval(0);
-    
+
     mpGameScene = new KBlocksScene(mpGameLogic, mGameCount);
-    
+
     mpGameView = new KBlocksView(mpGameScene, this);
     mpGameView->show();
     setCentralWidget(mpGameView);
-    
+
     mUpdateInterval = 1000;
     mUpdateTimer.setInterval(mUpdateInterval);
-    connect(&mUpdateTimer, SIGNAL(timeout()), SLOT(replayOneStep()));
+    connect(&mUpdateTimer, &QTimer::timeout, this, &KBlocksRepWin::replayOneStep);
     mUpdateTimer.stop();
-    
+
     mSnapshotFilename = QString("");
     mSnapshotFolder = QString("./snapshot/");
 }
@@ -82,12 +78,12 @@ void KBlocksRepWin::setReplayStepLength(int stepLen)
     mpGameReplayer->setStepLength(stepLen);
 }
 
-void KBlocksRepWin::setSnapshotFolder(const QString& folder)
+void KBlocksRepWin::setSnapshotFolder(const QString &folder)
 {
     mSnapshotFolder = folder;
 }
 
-void KBlocksRepWin::setSnapshotFilename(const QString& fileName)
+void KBlocksRepWin::setSnapshotFilename(const QString &fileName)
 {
     mSnapshotFilename = fileName;
 }
@@ -100,20 +96,20 @@ bool KBlocksRepWin::replayLoaded()
 void KBlocksRepWin::startReplay()
 {
     mpGameLogic->startGame(mGameCount);
-    
+
     mpGameScene->createGameItemGroups(mGameCount);
     mpGameScene->startGame();
-    
+
     mUpdateTimer.start();
 }
 
 void KBlocksRepWin::stopReplay()
 {
     mUpdateTimer.stop();
-    
+
     mpGameScene->stopGame();
     mpGameScene->deleteGameItemGroups();
-    
+
     mpGameLogic->stopGame();
 }
 
@@ -123,20 +119,19 @@ QString KBlocksRepWin::getTimeString()
     QTime tmpTime = QTime::currentTime();
     QString result;
     result = QString("%1-%2-%3_%4-%5-%6_%7")
-                    .arg(tmpDate.year(), 4, 10, QLatin1Char('0'))
-                    .arg(tmpDate.month(), 2, 10, QLatin1Char('0'))
-                    .arg(tmpDate.day(), 2, 10, QLatin1Char('0'))
-                    .arg(tmpTime.hour(), 2, 10, QLatin1Char('0'))
-                    .arg(tmpTime.minute(), 2, 10, QLatin1Char('0'))
-                    .arg(tmpTime.second(), 2, 10, QLatin1Char('0'))
-                    .arg(tmpTime.msec(), 3, 10, QLatin1Char('0'));
+             .arg(tmpDate.year(), 4, 10, QLatin1Char('0'))
+             .arg(tmpDate.month(), 2, 10, QLatin1Char('0'))
+             .arg(tmpDate.day(), 2, 10, QLatin1Char('0'))
+             .arg(tmpTime.hour(), 2, 10, QLatin1Char('0'))
+             .arg(tmpTime.minute(), 2, 10, QLatin1Char('0'))
+             .arg(tmpTime.second(), 2, 10, QLatin1Char('0'))
+             .arg(tmpTime.msec(), 3, 10, QLatin1Char('0'));
     return result;
 }
 
 void KBlocksRepWin::snapshotView()
 {
-    if (!mSnapshotFilename.isEmpty())
-    {
+    if (!mSnapshotFilename.isEmpty()) {
         //mSnapshoter = QPixmap::grabWindow(mpGameView->winId());
         mSnapshoter = QPixmap::grabWidget(this);
         QString tmpFilename = mSnapshotFolder + mSnapshotFilename + QString("_")
@@ -148,13 +143,11 @@ void KBlocksRepWin::snapshotView()
 void KBlocksRepWin::replayOneStep()
 {
     int tmpPieceChanged = 0;
-    if (!mpGameLogic->playRecordOneStep(&tmpPieceChanged))
-    {
+    if (!mpGameLogic->playRecordOneStep(&tmpPieceChanged)) {
         printf("Finished Replay!\n");
         mUpdateTimer.stop();
     }
-    if (tmpPieceChanged != 0)
-    {
+    if (tmpPieceChanged != 0) {
         snapshotView();
     }
 }
